# Minus80
[![Build Status](https://travis-ci.org/LinkageIO/Minus80.svg?branch=master)](https://travis-ci.org/LinkageIO/Minus80)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/de2595eaff5a47ab949616d5f12a2660)](https://www.codacy.com/app/schae234/Minus80?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=LinkageIO/Minus80&amp;utm_campaign=Badge_Grade)
[![Coverage Status](https://coveralls.io/repos/github/LinkageIO/Minus80/badge.svg?branch=master)](https://coveralls.io/github/LinkageIO/Minus80?branch=master)

This library is for freezing and integrating data. Modeled after how minus 80°C freezers work. 


## Installation

Option 1: Use pip to install the most recent tagged version:
```
pip install minus80
```

Option 2: Clone the repo manually and install the development version
```
git clone git@github.com:LinkageIO/Minus80.git
cd Minus80
python setup.py develop
```
**Note:** Both options require that you have `Python.h` on your system. [More info here](https://stackoverflow.com/questions/8282231/i-have-python-on-my-ubuntu-system-but-gcc-cant-find-python-h). On Ubuntu systems, you can run: `sudo apt-get install python-dev`.

## Documentation
http://linkage.io/docs/minus80/
